/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016 OX Software GmbH
 * Mail: info@open-xchange.com
 *
 * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
 */

define('io.ox/office/portal/action/toolbaractionstext', [
    'io.ox/office/portal/action/toolbaractionsimpl',
    'gettext!io.ox/office/portal/main'
], function (ToolbarActionsImpl, gt) {

    'use strict';

    /**
     * Creates all extensions points and bind actions for the portal toolbar.
     *
     * @constructor
     *
     */
    return new ToolbarActionsImpl({
        appBaseName: 'text',
        newDocText: gt('New text document'),
        newDocTextEncrypted: gt('New text document (encrypted)')
    });

});
